# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/tokenfactory/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.tokenfactory.v1beta1 import authorityMetadata_pb2 as osmosis_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2
from osmosis.tokenfactory.v1beta1 import params_pb2 as osmosis_dot_tokenfactory_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*osmosis/tokenfactory/v1beta1/genesis.proto\x12\x1cosmosis.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x34osmosis/tokenfactory/v1beta1/authorityMetadata.proto\x1a)osmosis/tokenfactory/v1beta1/params.proto\"\xad\x01\n\x0cGenesisState\x12:\n\x06params\x18\x01 \x01(\x0b\x32$.osmosis.tokenfactory.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x61\n\x0e\x66\x61\x63tory_denoms\x18\x02 \x03(\x0b\x32*.osmosis.tokenfactory.v1beta1.GenesisDenomB\x1d\xf2\xde\x1f\x15yaml:\"factory_denoms\"\xc8\xde\x1f\x00\"\xaa\x01\n\x0cGenesisDenom\x12\x1f\n\x05\x64\x65nom\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"\x12s\n\x12\x61uthority_metadata\x18\x02 \x01(\x0b\x32\x34.osmosis.tokenfactory.v1beta1.DenomAuthorityMetadataB!\xf2\xde\x1f\x19yaml:\"authority_metadata\"\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\x42:Z8github.com/osmosis-labs/osmosis/v14/x/tokenfactory/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.tokenfactory.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/osmosis-labs/osmosis/v14/x/tokenfactory/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['factory_denoms']._options = None
  _GENESISSTATE.fields_by_name['factory_denoms']._serialized_options = b'\362\336\037\025yaml:\"factory_denoms\"\310\336\037\000'
  _GENESISDENOM.fields_by_name['denom']._options = None
  _GENESISDENOM.fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _GENESISDENOM.fields_by_name['authority_metadata']._options = None
  _GENESISDENOM.fields_by_name['authority_metadata']._serialized_options = b'\362\336\037\031yaml:\"authority_metadata\"\310\336\037\000'
  _GENESISDENOM._options = None
  _GENESISDENOM._serialized_options = b'\350\240\037\001'
  _GENESISSTATE._serialized_start=196
  _GENESISSTATE._serialized_end=369
  _GENESISDENOM._serialized_start=372
  _GENESISDENOM._serialized_end=542
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/pool-incentives/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from osmosis.pool_incentives.v1beta1 import incentives_pb2 as osmosis_dot_pool__incentives_dot_v1beta1_dot_incentives__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-osmosis/pool-incentives/v1beta1/genesis.proto\x12\x1eosmosis.poolincentives.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x30osmosis/pool-incentives/v1beta1/incentives.proto\"\xe9\x02\n\x0cGenesisState\x12<\n\x06params\x18\x01 \x01(\x0b\x32&.osmosis.poolincentives.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\\\n\x12lockable_durations\x18\x02 \x03(\x0b\x32\x19.google.protobuf.DurationB%\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x19yaml:\"lockable_durations\"\x12X\n\ndistr_info\x18\x03 \x01(\x0b\x32).osmosis.poolincentives.v1beta1.DistrInfoB\x19\xc8\xde\x1f\x01\xf2\xde\x1f\x11yaml:\"distr_info\"\x12\x63\n\x0epool_to_gauges\x18\x04 \x01(\x0b\x32,.osmosis.poolincentives.v1beta1.PoolToGaugesB\x1d\xc8\xde\x1f\x01\xf2\xde\x1f\x15yaml:\"pool_to_gauges\"B=Z;github.com/osmosis-labs/osmosis/v14/x/pool-incentives/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.pool_incentives.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/osmosis-labs/osmosis/v14/x/pool-incentives/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['lockable_durations']._options = None
  _GENESISSTATE.fields_by_name['lockable_durations']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\031yaml:\"lockable_durations\"'
  _GENESISSTATE.fields_by_name['distr_info']._options = None
  _GENESISSTATE.fields_by_name['distr_info']._serialized_options = b'\310\336\037\001\362\336\037\021yaml:\"distr_info\"'
  _GENESISSTATE.fields_by_name['pool_to_gauges']._options = None
  _GENESISSTATE.fields_by_name['pool_to_gauges']._serialized_options = b'\310\336\037\001\362\336\037\025yaml:\"pool_to_gauges\"'
  _GENESISSTATE._serialized_start=186
  _GENESISSTATE._serialized_end=547
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.superfluid.query_pb2

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.QueryParamsRequest,
        osmosis.superfluid.query_pb2.QueryParamsResponse,
    ]
    """Params returns the total set of superfluid parameters."""
    AssetType: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.AssetTypeRequest,
        osmosis.superfluid.query_pb2.AssetTypeResponse,
    ]
    """Returns superfluid asset type, whether if it's a native asset or an lp
    share.
    """
    AllAssets: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.AllAssetsRequest,
        osmosis.superfluid.query_pb2.AllAssetsResponse,
    ]
    """Returns all registered superfluid assets."""
    AssetMultiplier: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.AssetMultiplierRequest,
        osmosis.superfluid.query_pb2.AssetMultiplierResponse,
    ]
    """Returns the osmo equivalent multiplier used in the most recent epoch."""
    AllIntermediaryAccounts: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.AllIntermediaryAccountsRequest,
        osmosis.superfluid.query_pb2.AllIntermediaryAccountsResponse,
    ]
    """Returns all superfluid intermediary accounts."""
    ConnectedIntermediaryAccount: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.ConnectedIntermediaryAccountRequest,
        osmosis.superfluid.query_pb2.ConnectedIntermediaryAccountResponse,
    ]
    """Returns intermediary account connected to a superfluid staked lock by id"""
    TotalDelegationByValidatorForDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.QueryTotalDelegationByValidatorForDenomRequest,
        osmosis.superfluid.query_pb2.QueryTotalDelegationByValidatorForDenomResponse,
    ]
    """Returns the amount of delegations of specific denom for all validators"""
    TotalSuperfluidDelegations: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.TotalSuperfluidDelegationsRequest,
        osmosis.superfluid.query_pb2.TotalSuperfluidDelegationsResponse,
    ]
    """Returns the total amount of osmo superfluidly staked.
    Response is denominated in uosmo.
    """
    SuperfluidDelegationAmount: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.SuperfluidDelegationAmountRequest,
        osmosis.superfluid.query_pb2.SuperfluidDelegationAmountResponse,
    ]
    """Returns the coins superfluid delegated for the delegator, validator, denom
    triplet
    """
    SuperfluidDelegationsByDelegator: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.SuperfluidDelegationsByDelegatorRequest,
        osmosis.superfluid.query_pb2.SuperfluidDelegationsByDelegatorResponse,
    ]
    """Returns all the delegated superfluid poistions for a specific delegator."""
    SuperfluidUndelegationsByDelegator: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.SuperfluidUndelegationsByDelegatorRequest,
        osmosis.superfluid.query_pb2.SuperfluidUndelegationsByDelegatorResponse,
    ]
    """Returns all the undelegating superfluid poistions for a specific delegator."""
    SuperfluidDelegationsByValidatorDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.SuperfluidDelegationsByValidatorDenomRequest,
        osmosis.superfluid.query_pb2.SuperfluidDelegationsByValidatorDenomResponse,
    ]
    """Returns all the superfluid positions of a specific denom delegated to one
    validator
    """
    EstimateSuperfluidDelegatedAmountByValidatorDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.EstimateSuperfluidDelegatedAmountByValidatorDenomRequest,
        osmosis.superfluid.query_pb2.EstimateSuperfluidDelegatedAmountByValidatorDenomResponse,
    ]
    """Returns the amount of a specific denom delegated to a specific validator
    This is labeled an estimate, because the way it calculates the amount can
    lead rounding errors from the true delegated amount
    """
    TotalDelegationByDelegator: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.QueryTotalDelegationByDelegatorRequest,
        osmosis.superfluid.query_pb2.QueryTotalDelegationByDelegatorResponse,
    ]
    """Returns the specified delegations for a specific delegator"""
    UnpoolWhitelist: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.query_pb2.QueryUnpoolWhitelistRequest,
        osmosis.superfluid.query_pb2.QueryUnpoolWhitelistResponse,
    ]
    """Returns a list of whitelisted pool ids to unpool."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.superfluid.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.QueryParamsResponse:
        """Params returns the total set of superfluid parameters."""
    @abc.abstractmethod
    def AssetType(
        self,
        request: osmosis.superfluid.query_pb2.AssetTypeRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.AssetTypeResponse:
        """Returns superfluid asset type, whether if it's a native asset or an lp
        share.
        """
    @abc.abstractmethod
    def AllAssets(
        self,
        request: osmosis.superfluid.query_pb2.AllAssetsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.AllAssetsResponse:
        """Returns all registered superfluid assets."""
    @abc.abstractmethod
    def AssetMultiplier(
        self,
        request: osmosis.superfluid.query_pb2.AssetMultiplierRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.AssetMultiplierResponse:
        """Returns the osmo equivalent multiplier used in the most recent epoch."""
    @abc.abstractmethod
    def AllIntermediaryAccounts(
        self,
        request: osmosis.superfluid.query_pb2.AllIntermediaryAccountsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.AllIntermediaryAccountsResponse:
        """Returns all superfluid intermediary accounts."""
    @abc.abstractmethod
    def ConnectedIntermediaryAccount(
        self,
        request: osmosis.superfluid.query_pb2.ConnectedIntermediaryAccountRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.ConnectedIntermediaryAccountResponse:
        """Returns intermediary account connected to a superfluid staked lock by id"""
    @abc.abstractmethod
    def TotalDelegationByValidatorForDenom(
        self,
        request: osmosis.superfluid.query_pb2.QueryTotalDelegationByValidatorForDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.QueryTotalDelegationByValidatorForDenomResponse:
        """Returns the amount of delegations of specific denom for all validators"""
    @abc.abstractmethod
    def TotalSuperfluidDelegations(
        self,
        request: osmosis.superfluid.query_pb2.TotalSuperfluidDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.TotalSuperfluidDelegationsResponse:
        """Returns the total amount of osmo superfluidly staked.
        Response is denominated in uosmo.
        """
    @abc.abstractmethod
    def SuperfluidDelegationAmount(
        self,
        request: osmosis.superfluid.query_pb2.SuperfluidDelegationAmountRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.SuperfluidDelegationAmountResponse:
        """Returns the coins superfluid delegated for the delegator, validator, denom
        triplet
        """
    @abc.abstractmethod
    def SuperfluidDelegationsByDelegator(
        self,
        request: osmosis.superfluid.query_pb2.SuperfluidDelegationsByDelegatorRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.SuperfluidDelegationsByDelegatorResponse:
        """Returns all the delegated superfluid poistions for a specific delegator."""
    @abc.abstractmethod
    def SuperfluidUndelegationsByDelegator(
        self,
        request: osmosis.superfluid.query_pb2.SuperfluidUndelegationsByDelegatorRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.SuperfluidUndelegationsByDelegatorResponse:
        """Returns all the undelegating superfluid poistions for a specific delegator."""
    @abc.abstractmethod
    def SuperfluidDelegationsByValidatorDenom(
        self,
        request: osmosis.superfluid.query_pb2.SuperfluidDelegationsByValidatorDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.SuperfluidDelegationsByValidatorDenomResponse:
        """Returns all the superfluid positions of a specific denom delegated to one
        validator
        """
    @abc.abstractmethod
    def EstimateSuperfluidDelegatedAmountByValidatorDenom(
        self,
        request: osmosis.superfluid.query_pb2.EstimateSuperfluidDelegatedAmountByValidatorDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.EstimateSuperfluidDelegatedAmountByValidatorDenomResponse:
        """Returns the amount of a specific denom delegated to a specific validator
        This is labeled an estimate, because the way it calculates the amount can
        lead rounding errors from the true delegated amount
        """
    @abc.abstractmethod
    def TotalDelegationByDelegator(
        self,
        request: osmosis.superfluid.query_pb2.QueryTotalDelegationByDelegatorRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.QueryTotalDelegationByDelegatorResponse:
        """Returns the specified delegations for a specific delegator"""
    @abc.abstractmethod
    def UnpoolWhitelist(
        self,
        request: osmosis.superfluid.query_pb2.QueryUnpoolWhitelistRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.query_pb2.QueryUnpoolWhitelistResponse:
        """Returns a list of whitelisted pool ids to unpool."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import osmosis.downtime_detector.v1beta1.downtime_duration_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RecoveredSinceDowntimeOfLengthRequest(google.protobuf.message.Message):
    """Query for has it been at least $RECOVERY_DURATION units of time,
    since the chain has been down for $DOWNTIME_DURATION.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNTIME_FIELD_NUMBER: builtins.int
    RECOVERY_FIELD_NUMBER: builtins.int
    downtime: osmosis.downtime_detector.v1beta1.downtime_duration_pb2.Downtime.ValueType
    @property
    def recovery(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        downtime: osmosis.downtime_detector.v1beta1.downtime_duration_pb2.Downtime.ValueType = ...,
        recovery: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recovery", b"recovery"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["downtime", b"downtime", "recovery", b"recovery"]) -> None: ...

global___RecoveredSinceDowntimeOfLengthRequest = RecoveredSinceDowntimeOfLengthRequest

@typing_extensions.final
class RecoveredSinceDowntimeOfLengthResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESFULLY_RECOVERED_FIELD_NUMBER: builtins.int
    succesfully_recovered: builtins.bool
    def __init__(
        self,
        *,
        succesfully_recovered: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["succesfully_recovered", b"succesfully_recovered"]) -> None: ...

global___RecoveredSinceDowntimeOfLengthResponse = RecoveredSinceDowntimeOfLengthResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TwapRecord(google.protobuf.message.Message):
    """A TWAP record should be indexed in state by pool_id, (asset pair), timestamp
    The asset pair assets should be lexicographically sorted.
    Technically (pool_id, asset_0_denom, asset_1_denom, height) do not need to
    appear in the struct however we view this as the wrong performance tradeoff
    given SDK today. Would rather we optimize for readability and correctness,
    than an optimal state storage format. The system bottleneck is elsewhere for
    now.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    ASSET0_DENOM_FIELD_NUMBER: builtins.int
    ASSET1_DENOM_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    P0_LAST_SPOT_PRICE_FIELD_NUMBER: builtins.int
    P1_LAST_SPOT_PRICE_FIELD_NUMBER: builtins.int
    P0_ARITHMETIC_TWAP_ACCUMULATOR_FIELD_NUMBER: builtins.int
    P1_ARITHMETIC_TWAP_ACCUMULATOR_FIELD_NUMBER: builtins.int
    GEOMETRIC_TWAP_ACCUMULATOR_FIELD_NUMBER: builtins.int
    LAST_ERROR_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    asset0_denom: builtins.str
    """Lexicographically smaller denom of the pair"""
    asset1_denom: builtins.str
    """Lexicographically larger denom of the pair"""
    height: builtins.int
    """height this record corresponds to, for debugging purposes"""
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """This field should only exist until we have a global registry in the state
        machine, mapping prior block heights within {TIME RANGE} to times.
        """
    p0_last_spot_price: builtins.str
    """We store the last spot prices in the struct, so that we can interpolate
    accumulator values for times between when accumulator records are stored.
    """
    p1_last_spot_price: builtins.str
    p0_arithmetic_twap_accumulator: builtins.str
    p1_arithmetic_twap_accumulator: builtins.str
    geometric_twap_accumulator: builtins.str
    @property
    def last_error_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """This field contains the time in which the last spot price error occured.
        It is used to alert the caller if they are getting a potentially erroneous
        TWAP, due to an unforeseen underlying error.
        """
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        asset0_denom: builtins.str = ...,
        asset1_denom: builtins.str = ...,
        height: builtins.int = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        p0_last_spot_price: builtins.str = ...,
        p1_last_spot_price: builtins.str = ...,
        p0_arithmetic_twap_accumulator: builtins.str = ...,
        p1_arithmetic_twap_accumulator: builtins.str = ...,
        geometric_twap_accumulator: builtins.str = ...,
        last_error_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_error_time", b"last_error_time", "time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset0_denom", b"asset0_denom", "asset1_denom", b"asset1_denom", "geometric_twap_accumulator", b"geometric_twap_accumulator", "height", b"height", "last_error_time", b"last_error_time", "p0_arithmetic_twap_accumulator", b"p0_arithmetic_twap_accumulator", "p0_last_spot_price", b"p0_last_spot_price", "p1_arithmetic_twap_accumulator", b"p1_arithmetic_twap_accumulator", "p1_last_spot_price", b"p1_last_spot_price", "pool_id", b"pool_id", "time", b"time"]) -> None: ...

global___TwapRecord = TwapRecord



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import abc
import cosmos.feegrant.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the feegrant msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    GrantAllowance: grpc.UnaryUnaryMultiCallable[
        cosmos.feegrant.v1beta1.tx_pb2.MsgGrantAllowance,
        cosmos.feegrant.v1beta1.tx_pb2.MsgGrantAllowanceResponse,
    ]
    """GrantAllowance grants fee allowance to the grantee on the granter's
    account with the provided expiration time.
    """
    RevokeAllowance: grpc.UnaryUnaryMultiCallable[
        cosmos.feegrant.v1beta1.tx_pb2.MsgRevokeAllowance,
        cosmos.feegrant.v1beta1.tx_pb2.MsgRevokeAllowanceResponse,
    ]
    """RevokeAllowance revokes any fee allowance of granter's account that
    has been granted to the grantee.
    """

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the feegrant msg service."""

    @abc.abstractmethod
    def GrantAllowance(
        self,
        request: cosmos.feegrant.v1beta1.tx_pb2.MsgGrantAllowance,
        context: grpc.ServicerContext,
    ) -> cosmos.feegrant.v1beta1.tx_pb2.MsgGrantAllowanceResponse:
        """GrantAllowance grants fee allowance to the grantee on the granter's
        account with the provided expiration time.
        """
    @abc.abstractmethod
    def RevokeAllowance(
        self,
        request: cosmos.feegrant.v1beta1.tx_pb2.MsgRevokeAllowance,
        context: grpc.ServicerContext,
    ) -> cosmos.feegrant.v1beta1.tx_pb2.MsgRevokeAllowanceResponse:
        """RevokeAllowance revokes any fee allowance of granter's account that
        has been granted to the grantee.
        """

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ConsensusParams(google.protobuf.message.Message):
    """ConsensusParams contains consensus critical parameters that determine the
    validity of blocks.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_FIELD_NUMBER: builtins.int
    EVIDENCE_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def block(self) -> global___BlockParams: ...
    @property
    def evidence(self) -> global___EvidenceParams: ...
    @property
    def validator(self) -> global___ValidatorParams: ...
    @property
    def version(self) -> global___VersionParams: ...
    def __init__(
        self,
        *,
        block: global___BlockParams | None = ...,
        evidence: global___EvidenceParams | None = ...,
        validator: global___ValidatorParams | None = ...,
        version: global___VersionParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block", b"block", "evidence", b"evidence", "validator", b"validator", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block", b"block", "evidence", b"evidence", "validator", b"validator", "version", b"version"]) -> None: ...

global___ConsensusParams = ConsensusParams

@typing_extensions.final
class BlockParams(google.protobuf.message.Message):
    """BlockParams contains limits on the block size."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_BYTES_FIELD_NUMBER: builtins.int
    MAX_GAS_FIELD_NUMBER: builtins.int
    TIME_IOTA_MS_FIELD_NUMBER: builtins.int
    max_bytes: builtins.int
    """Max block size, in bytes.
    Note: must be greater than 0
    """
    max_gas: builtins.int
    """Max gas per block.
    Note: must be greater or equal to -1
    """
    time_iota_ms: builtins.int
    """Minimum time increment between consecutive blocks (in milliseconds) If the
    block header timestamp is ahead of the system clock, decrease this value.

    Not exposed to the application.
    """
    def __init__(
        self,
        *,
        max_bytes: builtins.int = ...,
        max_gas: builtins.int = ...,
        time_iota_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_bytes", b"max_bytes", "max_gas", b"max_gas", "time_iota_ms", b"time_iota_ms"]) -> None: ...

global___BlockParams = BlockParams

@typing_extensions.final
class EvidenceParams(google.protobuf.message.Message):
    """EvidenceParams determine how we handle evidence of malfeasance."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_AGE_NUM_BLOCKS_FIELD_NUMBER: builtins.int
    MAX_AGE_DURATION_FIELD_NUMBER: builtins.int
    MAX_BYTES_FIELD_NUMBER: builtins.int
    max_age_num_blocks: builtins.int
    """Max age of evidence, in blocks.

    The basic formula for calculating this is: MaxAgeDuration / {average block
    time}.
    """
    @property
    def max_age_duration(self) -> google.protobuf.duration_pb2.Duration:
        """Max age of evidence, in time.

        It should correspond with an app's "unbonding period" or other similar
        mechanism for handling [Nothing-At-Stake
        attacks](https://github.com/ethereum/wiki/wiki/Proof-of-Stake-FAQ#what-is-the-nothing-at-stake-problem-and-how-can-it-be-fixed).
        """
    max_bytes: builtins.int
    """This sets the maximum size of total evidence in bytes that can be committed in a single block.
    and should fall comfortably under the max block bytes.
    Default is 1048576 or 1MB
    """
    def __init__(
        self,
        *,
        max_age_num_blocks: builtins.int = ...,
        max_age_duration: google.protobuf.duration_pb2.Duration | None = ...,
        max_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_age_duration", b"max_age_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_age_duration", b"max_age_duration", "max_age_num_blocks", b"max_age_num_blocks", "max_bytes", b"max_bytes"]) -> None: ...

global___EvidenceParams = EvidenceParams

@typing_extensions.final
class ValidatorParams(google.protobuf.message.Message):
    """ValidatorParams restrict the public key types validators can use.
    NOTE: uses ABCI pubkey naming, not Amino names.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUB_KEY_TYPES_FIELD_NUMBER: builtins.int
    @property
    def pub_key_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        pub_key_types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pub_key_types", b"pub_key_types"]) -> None: ...

global___ValidatorParams = ValidatorParams

@typing_extensions.final
class VersionParams(google.protobuf.message.Message):
    """VersionParams contains the ABCI application version."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_VERSION_FIELD_NUMBER: builtins.int
    app_version: builtins.int
    def __init__(
        self,
        *,
        app_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_version", b"app_version"]) -> None: ...

global___VersionParams = VersionParams

@typing_extensions.final
class HashedParams(google.protobuf.message.Message):
    """HashedParams is a subset of ConsensusParams.

    It is hashed into the Header.ConsensusHash.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_MAX_BYTES_FIELD_NUMBER: builtins.int
    BLOCK_MAX_GAS_FIELD_NUMBER: builtins.int
    block_max_bytes: builtins.int
    block_max_gas: builtins.int
    def __init__(
        self,
        *,
        block_max_bytes: builtins.int = ...,
        block_max_gas: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_max_bytes", b"block_max_bytes", "block_max_gas", b"block_max_gas"]) -> None: ...

global___HashedParams = HashedParams



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/pool-models/stableswap/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.gamm.pool_models.stableswap import stableswap_pool_pb2 as osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_stableswap__pool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,osmosis/gamm/pool-models/stableswap/tx.proto\x12*osmosis.gamm.poolmodels.stableswap.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x39osmosis/gamm/pool-models/stableswap/stableswap_pool.proto\"\xd5\x03\n\x17MsgCreateStableswapPool\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12\x63\n\x0bpool_params\x18\x02 \x01(\x0b\x32\x36.osmosis.gamm.poolmodels.stableswap.v1beta1.PoolParamsB\x16\xf2\xde\x1f\x12yaml:\"pool_params\"\x12k\n\x16initial_pool_liquidity\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12=\n\x0fscaling_factors\x18\x04 \x03(\x04\x42$\xf2\xde\x1f yaml:\"stableswap_scaling_factor\"\x12=\n\x14\x66uture_pool_governor\x18\x05 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"future_pool_governor\"\x12G\n\x19scaling_factor_controller\x18\x06 \x01(\tB$\xf2\xde\x1f yaml:\"scaling_factor_controller\"\">\n\x1fMsgCreateStableswapPoolResponse\x12\x1b\n\x07pool_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06PoolID\"\xa2\x01\n!MsgStableSwapAdjustScalingFactors\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12\x1b\n\x07pool_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06PoolID\x12=\n\x0fscaling_factors\x18\x03 \x03(\x04\x42$\xf2\xde\x1f yaml:\"stableswap_scaling_factor\"\"+\n)MsgStableSwapAdjustScalingFactorsResponse2\xf9\x02\n\x03Msg\x12\xa8\x01\n\x14\x43reateStableswapPool\x12\x43.osmosis.gamm.poolmodels.stableswap.v1beta1.MsgCreateStableswapPool\x1aK.osmosis.gamm.poolmodels.stableswap.v1beta1.MsgCreateStableswapPoolResponse\x12\xc6\x01\n\x1eStableSwapAdjustScalingFactors\x12M.osmosis.gamm.poolmodels.stableswap.v1beta1.MsgStableSwapAdjustScalingFactors\x1aU.osmosis.gamm.poolmodels.stableswap.v1beta1.MsgStableSwapAdjustScalingFactorsResponseBCZAgithub.com/osmosis-labs/osmosis/v14/x/gamm/pool-models/stableswapb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.pool_models.stableswap.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZAgithub.com/osmosis-labs/osmosis/v14/x/gamm/pool-models/stableswap'
  _MSGCREATESTABLESWAPPOOL.fields_by_name['sender']._options = None
  _MSGCREATESTABLESWAPPOOL.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGCREATESTABLESWAPPOOL.fields_by_name['pool_params']._options = None
  _MSGCREATESTABLESWAPPOOL.fields_by_name['pool_params']._serialized_options = b'\362\336\037\022yaml:\"pool_params\"'
  _MSGCREATESTABLESWAPPOOL.fields_by_name['initial_pool_liquidity']._options = None
  _MSGCREATESTABLESWAPPOOL.fields_by_name['initial_pool_liquidity']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATESTABLESWAPPOOL.fields_by_name['scaling_factors']._options = None
  _MSGCREATESTABLESWAPPOOL.fields_by_name['scaling_factors']._serialized_options = b'\362\336\037 yaml:\"stableswap_scaling_factor\"'
  _MSGCREATESTABLESWAPPOOL.fields_by_name['future_pool_governor']._options = None
  _MSGCREATESTABLESWAPPOOL.fields_by_name['future_pool_governor']._serialized_options = b'\362\336\037\033yaml:\"future_pool_governor\"'
  _MSGCREATESTABLESWAPPOOL.fields_by_name['scaling_factor_controller']._options = None
  _MSGCREATESTABLESWAPPOOL.fields_by_name['scaling_factor_controller']._serialized_options = b'\362\336\037 yaml:\"scaling_factor_controller\"'
  _MSGCREATESTABLESWAPPOOLRESPONSE.fields_by_name['pool_id']._options = None
  _MSGCREATESTABLESWAPPOOLRESPONSE.fields_by_name['pool_id']._serialized_options = b'\342\336\037\006PoolID'
  _MSGSTABLESWAPADJUSTSCALINGFACTORS.fields_by_name['sender']._options = None
  _MSGSTABLESWAPADJUSTSCALINGFACTORS.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGSTABLESWAPADJUSTSCALINGFACTORS.fields_by_name['pool_id']._options = None
  _MSGSTABLESWAPADJUSTSCALINGFACTORS.fields_by_name['pool_id']._serialized_options = b'\342\336\037\006PoolID'
  _MSGSTABLESWAPADJUSTSCALINGFACTORS.fields_by_name['scaling_factors']._options = None
  _MSGSTABLESWAPADJUSTSCALINGFACTORS.fields_by_name['scaling_factors']._serialized_options = b'\362\336\037 yaml:\"stableswap_scaling_factor\"'
  _MSGCREATESTABLESWAPPOOL._serialized_start=206
  _MSGCREATESTABLESWAPPOOL._serialized_end=675
  _MSGCREATESTABLESWAPPOOLRESPONSE._serialized_start=677
  _MSGCREATESTABLESWAPPOOLRESPONSE._serialized_end=739
  _MSGSTABLESWAPADJUSTSCALINGFACTORS._serialized_start=742
  _MSGSTABLESWAPADJUSTSCALINGFACTORS._serialized_end=904
  _MSGSTABLESWAPADJUSTSCALINGFACTORSRESPONSE._serialized_start=906
  _MSGSTABLESWAPADJUSTSCALINGFACTORSRESPONSE._serialized_end=949
  _MSG._serialized_start=952
  _MSG._serialized_end=1329
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.gamm.v1beta1 import tx_pb2 as osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.JoinPool = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/JoinPool',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinPool.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinPoolResponse.FromString,
        )
        self.ExitPool = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/ExitPool',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitPool.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitPoolResponse.FromString,
        )
        self.SwapExactAmountIn = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/SwapExactAmountIn',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountIn.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountInResponse.FromString,
        )
        self.SwapExactAmountOut = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/SwapExactAmountOut',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountOut.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountOutResponse.FromString,
        )
        self.JoinSwapExternAmountIn = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/JoinSwapExternAmountIn',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapExternAmountIn.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapExternAmountInResponse.FromString,
        )
        self.JoinSwapShareAmountOut = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/JoinSwapShareAmountOut',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapShareAmountOut.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapShareAmountOutResponse.FromString,
        )
        self.ExitSwapExternAmountOut = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/ExitSwapExternAmountOut',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapExternAmountOut.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapExternAmountOutResponse.FromString,
        )
        self.ExitSwapShareAmountIn = channel.unary_unary(
            '/osmosis.gamm.v1beta1.Msg/ExitSwapShareAmountIn',
            request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapShareAmountIn.SerializeToString,
            response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapShareAmountInResponse.FromString,
        )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def JoinPool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExitPool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SwapExactAmountIn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SwapExactAmountOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinSwapExternAmountIn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinSwapShareAmountOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExitSwapExternAmountOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExitSwapShareAmountIn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'JoinPool': grpc.unary_unary_rpc_method_handler(
            servicer.JoinPool,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinPool.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinPoolResponse.SerializeToString,
        ),
        'ExitPool': grpc.unary_unary_rpc_method_handler(
            servicer.ExitPool,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitPool.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitPoolResponse.SerializeToString,
        ),
        'SwapExactAmountIn': grpc.unary_unary_rpc_method_handler(
            servicer.SwapExactAmountIn,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountIn.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountInResponse.SerializeToString,
        ),
        'SwapExactAmountOut': grpc.unary_unary_rpc_method_handler(
            servicer.SwapExactAmountOut,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountOut.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountOutResponse.SerializeToString,
        ),
        'JoinSwapExternAmountIn': grpc.unary_unary_rpc_method_handler(
            servicer.JoinSwapExternAmountIn,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapExternAmountIn.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapExternAmountInResponse.SerializeToString,
        ),
        'JoinSwapShareAmountOut': grpc.unary_unary_rpc_method_handler(
            servicer.JoinSwapShareAmountOut,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapShareAmountOut.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapShareAmountOutResponse.SerializeToString,
        ),
        'ExitSwapExternAmountOut': grpc.unary_unary_rpc_method_handler(
            servicer.ExitSwapExternAmountOut,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapExternAmountOut.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapExternAmountOutResponse.SerializeToString,
        ),
        'ExitSwapShareAmountIn': grpc.unary_unary_rpc_method_handler(
            servicer.ExitSwapShareAmountIn,
            request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapShareAmountIn.FromString,
            response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapShareAmountInResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'osmosis.gamm.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def JoinPool(request,
                 target,
                 options=(),
                 channel_credentials=None,
                 call_credentials=None,
                 insecure=False,
                 compression=None,
                 wait_for_ready=None,
                 timeout=None,
                 metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/JoinPool',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinPool.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinPoolResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExitPool(request,
                 target,
                 options=(),
                 channel_credentials=None,
                 call_credentials=None,
                 insecure=False,
                 compression=None,
                 wait_for_ready=None,
                 timeout=None,
                 metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/ExitPool',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitPool.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitPoolResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SwapExactAmountIn(request,
                          target,
                          options=(),
                          channel_credentials=None,
                          call_credentials=None,
                          insecure=False,
                          compression=None,
                          wait_for_ready=None,
                          timeout=None,
                          metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/SwapExactAmountIn',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountIn.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountInResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SwapExactAmountOut(request,
                           target,
                           options=(),
                           channel_credentials=None,
                           call_credentials=None,
                           insecure=False,
                           compression=None,
                           wait_for_ready=None,
                           timeout=None,
                           metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/SwapExactAmountOut',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountOut.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgSwapExactAmountOutResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinSwapExternAmountIn(request,
                               target,
                               options=(),
                               channel_credentials=None,
                               call_credentials=None,
                               insecure=False,
                               compression=None,
                               wait_for_ready=None,
                               timeout=None,
                               metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/JoinSwapExternAmountIn',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapExternAmountIn.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapExternAmountInResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinSwapShareAmountOut(request,
                               target,
                               options=(),
                               channel_credentials=None,
                               call_credentials=None,
                               insecure=False,
                               compression=None,
                               wait_for_ready=None,
                               timeout=None,
                               metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/JoinSwapShareAmountOut',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapShareAmountOut.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgJoinSwapShareAmountOutResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExitSwapExternAmountOut(request,
                                target,
                                options=(),
                                channel_credentials=None,
                                call_credentials=None,
                                insecure=False,
                                compression=None,
                                wait_for_ready=None,
                                timeout=None,
                                metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/ExitSwapExternAmountOut',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapExternAmountOut.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapExternAmountOutResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExitSwapShareAmountIn(request,
                              target,
                              options=(),
                              channel_credentials=None,
                              call_credentials=None,
                              insecure=False,
                              compression=None,
                              wait_for_ready=None,
                              timeout=None,
                              metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Msg/ExitSwapShareAmountIn',
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapShareAmountIn.SerializeToString,
                                             osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2.MsgExitSwapShareAmountInResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DenomAuthorityMetadata(google.protobuf.message.Message):
    """DenomAuthorityMetadata specifies metadata for addresses that have specific
    capabilities over a token factory denom. Right now there is only one Admin
    permission, but is planned to be extended to the future.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_FIELD_NUMBER: builtins.int
    admin: builtins.str
    """Can be empty for no admin, or a valid osmosis address"""
    def __init__(
        self,
        *,
        admin: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin", b"admin"]) -> None: ...

global___DenomAuthorityMetadata = DenomAuthorityMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Minter(google.protobuf.message.Message):
    """Minter represents the minting state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFLATION_FIELD_NUMBER: builtins.int
    ANNUAL_PROVISIONS_FIELD_NUMBER: builtins.int
    inflation: builtins.str
    """current annual inflation rate"""
    annual_provisions: builtins.str
    """current annual expected provisions"""
    def __init__(
        self,
        *,
        inflation: builtins.str = ...,
        annual_provisions: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["annual_provisions", b"annual_provisions", "inflation", b"inflation"]) -> None: ...

global___Minter = Minter

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params holds parameters for the mint module."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MINT_DENOM_FIELD_NUMBER: builtins.int
    INFLATION_RATE_CHANGE_FIELD_NUMBER: builtins.int
    INFLATION_MAX_FIELD_NUMBER: builtins.int
    INFLATION_MIN_FIELD_NUMBER: builtins.int
    GOAL_BONDED_FIELD_NUMBER: builtins.int
    BLOCKS_PER_YEAR_FIELD_NUMBER: builtins.int
    mint_denom: builtins.str
    """type of coin to mint"""
    inflation_rate_change: builtins.str
    """maximum annual change in inflation rate"""
    inflation_max: builtins.str
    """maximum inflation rate"""
    inflation_min: builtins.str
    """minimum inflation rate"""
    goal_bonded: builtins.str
    """goal of percent bonded atoms"""
    blocks_per_year: builtins.int
    """expected blocks per year"""
    def __init__(
        self,
        *,
        mint_denom: builtins.str = ...,
        inflation_rate_change: builtins.str = ...,
        inflation_max: builtins.str = ...,
        inflation_min: builtins.str = ...,
        goal_bonded: builtins.str = ...,
        blocks_per_year: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["blocks_per_year", b"blocks_per_year", "goal_bonded", b"goal_bonded", "inflation_max", b"inflation_max", "inflation_min", b"inflation_min", "inflation_rate_change", b"inflation_rate_change", "mint_denom", b"mint_denom"]) -> None: ...

global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.incentives.gauge_pb2
import osmosis.pool_incentives.v1beta1.incentives_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryGaugeIdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___QueryGaugeIdsRequest = QueryGaugeIdsRequest

@typing_extensions.final
class QueryGaugeIdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GaugeIdWithDuration(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GAUGE_ID_FIELD_NUMBER: builtins.int
        DURATION_FIELD_NUMBER: builtins.int
        GAUGE_INCENTIVE_PERCENTAGE_FIELD_NUMBER: builtins.int
        gauge_id: builtins.int
        @property
        def duration(self) -> google.protobuf.duration_pb2.Duration: ...
        gauge_incentive_percentage: builtins.str
        def __init__(
            self,
            *,
            gauge_id: builtins.int = ...,
            duration: google.protobuf.duration_pb2.Duration | None = ...,
            gauge_incentive_percentage: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "gauge_id", b"gauge_id", "gauge_incentive_percentage", b"gauge_incentive_percentage"]) -> None: ...

    GAUGE_IDS_WITH_DURATION_FIELD_NUMBER: builtins.int
    @property
    def gauge_ids_with_duration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QueryGaugeIdsResponse.GaugeIdWithDuration]: ...
    def __init__(
        self,
        *,
        gauge_ids_with_duration: collections.abc.Iterable[global___QueryGaugeIdsResponse.GaugeIdWithDuration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gauge_ids_with_duration", b"gauge_ids_with_duration"]) -> None: ...

global___QueryGaugeIdsResponse = QueryGaugeIdsResponse

@typing_extensions.final
class QueryDistrInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryDistrInfoRequest = QueryDistrInfoRequest

@typing_extensions.final
class QueryDistrInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISTR_INFO_FIELD_NUMBER: builtins.int
    @property
    def distr_info(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo: ...
    def __init__(
        self,
        *,
        distr_info: osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info"]) -> None: ...

global___QueryDistrInfoResponse = QueryDistrInfoResponse

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.Params: ...
    def __init__(
        self,
        *,
        params: osmosis.pool_incentives.v1beta1.incentives_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse

@typing_extensions.final
class QueryLockableDurationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryLockableDurationsRequest = QueryLockableDurationsRequest

@typing_extensions.final
class QueryLockableDurationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKABLE_DURATIONS_FIELD_NUMBER: builtins.int
    @property
    def lockable_durations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.duration_pb2.Duration]: ...
    def __init__(
        self,
        *,
        lockable_durations: collections.abc.Iterable[google.protobuf.duration_pb2.Duration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lockable_durations", b"lockable_durations"]) -> None: ...

global___QueryLockableDurationsResponse = QueryLockableDurationsResponse

@typing_extensions.final
class QueryIncentivizedPoolsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryIncentivizedPoolsRequest = QueryIncentivizedPoolsRequest

@typing_extensions.final
class IncentivizedPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    LOCKABLE_DURATION_FIELD_NUMBER: builtins.int
    GAUGE_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    @property
    def lockable_duration(self) -> google.protobuf.duration_pb2.Duration: ...
    gauge_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        lockable_duration: google.protobuf.duration_pb2.Duration | None = ...,
        gauge_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lockable_duration", b"lockable_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gauge_id", b"gauge_id", "lockable_duration", b"lockable_duration", "pool_id", b"pool_id"]) -> None: ...

global___IncentivizedPool = IncentivizedPool

@typing_extensions.final
class QueryIncentivizedPoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCENTIVIZED_POOLS_FIELD_NUMBER: builtins.int
    @property
    def incentivized_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IncentivizedPool]: ...
    def __init__(
        self,
        *,
        incentivized_pools: collections.abc.Iterable[global___IncentivizedPool] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["incentivized_pools", b"incentivized_pools"]) -> None: ...

global___QueryIncentivizedPoolsResponse = QueryIncentivizedPoolsResponse

@typing_extensions.final
class QueryExternalIncentiveGaugesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryExternalIncentiveGaugesRequest = QueryExternalIncentiveGaugesRequest

@typing_extensions.final
class QueryExternalIncentiveGaugesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.incentives.gauge_pb2.Gauge]: ...
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[osmosis.incentives.gauge_pb2.Gauge] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___QueryExternalIncentiveGaugesResponse = QueryExternalIncentiveGaugesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.upgrade.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC upgrade querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    CurrentPlan: grpc.UnaryUnaryMultiCallable[
        cosmos.upgrade.v1beta1.query_pb2.QueryCurrentPlanRequest,
        cosmos.upgrade.v1beta1.query_pb2.QueryCurrentPlanResponse,
    ]
    """CurrentPlan queries the current upgrade plan."""
    AppliedPlan: grpc.UnaryUnaryMultiCallable[
        cosmos.upgrade.v1beta1.query_pb2.QueryAppliedPlanRequest,
        cosmos.upgrade.v1beta1.query_pb2.QueryAppliedPlanResponse,
    ]
    """AppliedPlan queries a previously applied upgrade plan by its name."""
    UpgradedConsensusState: grpc.UnaryUnaryMultiCallable[
        cosmos.upgrade.v1beta1.query_pb2.QueryUpgradedConsensusStateRequest,
        cosmos.upgrade.v1beta1.query_pb2.QueryUpgradedConsensusStateResponse,
    ]
    """UpgradedConsensusState queries the consensus state that will serve
    as a trusted kernel for the next version of this chain. It will only be
    stored at the last height of this chain.
    UpgradedConsensusState RPC not supported with legacy querier
    This rpc is deprecated now that IBC has its own replacement
    (https://github.com/cosmos/ibc-go/blob/2c880a22e9f9cc75f62b527ca94aa75ce1106001/proto/ibc/core/client/v1/query.proto#L54)
    """
    ModuleVersions: grpc.UnaryUnaryMultiCallable[
        cosmos.upgrade.v1beta1.query_pb2.QueryModuleVersionsRequest,
        cosmos.upgrade.v1beta1.query_pb2.QueryModuleVersionsResponse,
    ]
    """ModuleVersions queries the list of module versions from state.

    Since: cosmos-sdk 0.43
    """

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC upgrade querier service."""

    @abc.abstractmethod
    def CurrentPlan(
        self,
        request: cosmos.upgrade.v1beta1.query_pb2.QueryCurrentPlanRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.upgrade.v1beta1.query_pb2.QueryCurrentPlanResponse:
        """CurrentPlan queries the current upgrade plan."""
    @abc.abstractmethod
    def AppliedPlan(
        self,
        request: cosmos.upgrade.v1beta1.query_pb2.QueryAppliedPlanRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.upgrade.v1beta1.query_pb2.QueryAppliedPlanResponse:
        """AppliedPlan queries a previously applied upgrade plan by its name."""
    @abc.abstractmethod
    def UpgradedConsensusState(
        self,
        request: cosmos.upgrade.v1beta1.query_pb2.QueryUpgradedConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.upgrade.v1beta1.query_pb2.QueryUpgradedConsensusStateResponse:
        """UpgradedConsensusState queries the consensus state that will serve
        as a trusted kernel for the next version of this chain. It will only be
        stored at the last height of this chain.
        UpgradedConsensusState RPC not supported with legacy querier
        This rpc is deprecated now that IBC has its own replacement
        (https://github.com/cosmos/ibc-go/blob/2c880a22e9f9cc75f62b527ca94aa75ce1106001/proto/ibc/core/client/v1/query.proto#L54)
        """
    @abc.abstractmethod
    def ModuleVersions(
        self,
        request: cosmos.upgrade.v1beta1.query_pb2.QueryModuleVersionsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.upgrade.v1beta1.query_pb2.QueryModuleVersionsResponse:
        """ModuleVersions queries the list of module versions from state.

        Since: cosmos-sdk 0.43
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AppDescriptor(google.protobuf.message.Message):
    """AppDescriptor describes a cosmos-sdk based application"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHN_FIELD_NUMBER: builtins.int
    CHAIN_FIELD_NUMBER: builtins.int
    CODEC_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    QUERY_SERVICES_FIELD_NUMBER: builtins.int
    TX_FIELD_NUMBER: builtins.int
    @property
    def authn(self) -> global___AuthnDescriptor:
        """AuthnDescriptor provides information on how to authenticate transactions on the application
        NOTE: experimental and subject to change in future releases.
        """
    @property
    def chain(self) -> global___ChainDescriptor:
        """chain provides the chain descriptor"""
    @property
    def codec(self) -> global___CodecDescriptor:
        """codec provides metadata information regarding codec related types"""
    @property
    def configuration(self) -> global___ConfigurationDescriptor:
        """configuration provides metadata information regarding the sdk.Config type"""
    @property
    def query_services(self) -> global___QueryServicesDescriptor:
        """query_services provides metadata information regarding the available queriable endpoints"""
    @property
    def tx(self) -> global___TxDescriptor:
        """tx provides metadata information regarding how to send transactions to the given application"""
    def __init__(
        self,
        *,
        authn: global___AuthnDescriptor | None = ...,
        chain: global___ChainDescriptor | None = ...,
        codec: global___CodecDescriptor | None = ...,
        configuration: global___ConfigurationDescriptor | None = ...,
        query_services: global___QueryServicesDescriptor | None = ...,
        tx: global___TxDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authn", b"authn", "chain", b"chain", "codec", b"codec", "configuration", b"configuration", "query_services", b"query_services", "tx", b"tx"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authn", b"authn", "chain", b"chain", "codec", b"codec", "configuration", b"configuration", "query_services", b"query_services", "tx", b"tx"]) -> None: ...

global___AppDescriptor = AppDescriptor

@typing_extensions.final
class TxDescriptor(google.protobuf.message.Message):
    """TxDescriptor describes the accepted transaction type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULLNAME_FIELD_NUMBER: builtins.int
    MSGS_FIELD_NUMBER: builtins.int
    fullname: builtins.str
    """fullname is the protobuf fullname of the raw transaction type (for instance the tx.Tx type)
    it is not meant to support polymorphism of transaction types, it is supposed to be used by
    reflection clients to understand if they can handle a specific transaction type in an application.
    """
    @property
    def msgs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MsgDescriptor]:
        """msgs lists the accepted application messages (sdk.Msg)"""
    def __init__(
        self,
        *,
        fullname: builtins.str = ...,
        msgs: collections.abc.Iterable[global___MsgDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fullname", b"fullname", "msgs", b"msgs"]) -> None: ...

global___TxDescriptor = TxDescriptor

@typing_extensions.final
class AuthnDescriptor(google.protobuf.message.Message):
    """AuthnDescriptor provides information on how to sign transactions without relying
    on the online RPCs GetTxMetadata and CombineUnsignedTxAndSignatures
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGN_MODES_FIELD_NUMBER: builtins.int
    @property
    def sign_modes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SigningModeDescriptor]:
        """sign_modes defines the supported signature algorithm"""
    def __init__(
        self,
        *,
        sign_modes: collections.abc.Iterable[global___SigningModeDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sign_modes", b"sign_modes"]) -> None: ...

global___AuthnDescriptor = AuthnDescriptor

@typing_extensions.final
class SigningModeDescriptor(google.protobuf.message.Message):
    """SigningModeDescriptor provides information on a signing flow of the application
    NOTE(fdymylja): here we could go as far as providing an entire flow on how
    to sign a message given a SigningModeDescriptor, but it's better to think about
    this another time
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    AUTHN_INFO_PROVIDER_METHOD_FULLNAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name defines the unique name of the signing mode"""
    number: builtins.int
    """number is the unique int32 identifier for the sign_mode enum"""
    authn_info_provider_method_fullname: builtins.str
    """authn_info_provider_method_fullname defines the fullname of the method to call to get
    the metadata required to authenticate using the provided sign_modes
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        number: builtins.int = ...,
        authn_info_provider_method_fullname: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authn_info_provider_method_fullname", b"authn_info_provider_method_fullname", "name", b"name", "number", b"number"]) -> None: ...

global___SigningModeDescriptor = SigningModeDescriptor

@typing_extensions.final
class ChainDescriptor(google.protobuf.message.Message):
    """ChainDescriptor describes chain information of the application"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """id is the chain id"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ChainDescriptor = ChainDescriptor

@typing_extensions.final
class CodecDescriptor(google.protobuf.message.Message):
    """CodecDescriptor describes the registered interfaces and provides metadata information on the types"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERFACES_FIELD_NUMBER: builtins.int
    @property
    def interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InterfaceDescriptor]:
        """interfaces is a list of the registerted interfaces descriptors"""
    def __init__(
        self,
        *,
        interfaces: collections.abc.Iterable[global___InterfaceDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interfaces", b"interfaces"]) -> None: ...

global___CodecDescriptor = CodecDescriptor

@typing_extensions.final
class InterfaceDescriptor(google.protobuf.message.Message):
    """InterfaceDescriptor describes the implementation of an interface"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULLNAME_FIELD_NUMBER: builtins.int
    INTERFACE_ACCEPTING_MESSAGES_FIELD_NUMBER: builtins.int
    INTERFACE_IMPLEMENTERS_FIELD_NUMBER: builtins.int
    fullname: builtins.str
    """fullname is the name of the interface"""
    @property
    def interface_accepting_messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InterfaceAcceptingMessageDescriptor]:
        """interface_accepting_messages contains information regarding the proto messages which contain the interface as
        google.protobuf.Any field
        """
    @property
    def interface_implementers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InterfaceImplementerDescriptor]:
        """interface_implementers is a list of the descriptors of the interface implementers"""
    def __init__(
        self,
        *,
        fullname: builtins.str = ...,
        interface_accepting_messages: collections.abc.Iterable[global___InterfaceAcceptingMessageDescriptor] | None = ...,
        interface_implementers: collections.abc.Iterable[global___InterfaceImplementerDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fullname", b"fullname", "interface_accepting_messages", b"interface_accepting_messages", "interface_implementers", b"interface_implementers"]) -> None: ...

global___InterfaceDescriptor = InterfaceDescriptor

@typing_extensions.final
class InterfaceImplementerDescriptor(google.protobuf.message.Message):
    """InterfaceImplementerDescriptor describes an interface implementer"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULLNAME_FIELD_NUMBER: builtins.int
    TYPE_URL_FIELD_NUMBER: builtins.int
    fullname: builtins.str
    """fullname is the protobuf queryable name of the interface implementer"""
    type_url: builtins.str
    """type_url defines the type URL used when marshalling the type as any
    this is required so we can provide type safe google.protobuf.Any marshalling and
    unmarshalling, making sure that we don't accept just 'any' type
    in our interface fields
    """
    def __init__(
        self,
        *,
        fullname: builtins.str = ...,
        type_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fullname", b"fullname", "type_url", b"type_url"]) -> None: ...

global___InterfaceImplementerDescriptor = InterfaceImplementerDescriptor

@typing_extensions.final
class InterfaceAcceptingMessageDescriptor(google.protobuf.message.Message):
    """InterfaceAcceptingMessageDescriptor describes a protobuf message which contains
    an interface represented as a google.protobuf.Any
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULLNAME_FIELD_NUMBER: builtins.int
    FIELD_DESCRIPTOR_NAMES_FIELD_NUMBER: builtins.int
    fullname: builtins.str
    """fullname is the protobuf fullname of the type containing the interface"""
    @property
    def field_descriptor_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """field_descriptor_names is a list of the protobuf name (not fullname) of the field
        which contains the interface as google.protobuf.Any (the interface is the same, but
        it can be in multiple fields of the same proto message)
        """
    def __init__(
        self,
        *,
        fullname: builtins.str = ...,
        field_descriptor_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_descriptor_names", b"field_descriptor_names", "fullname", b"fullname"]) -> None: ...

global___InterfaceAcceptingMessageDescriptor = InterfaceAcceptingMessageDescriptor

@typing_extensions.final
class ConfigurationDescriptor(google.protobuf.message.Message):
    """ConfigurationDescriptor contains metadata information on the sdk.Config"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BECH32_ACCOUNT_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    bech32_account_address_prefix: builtins.str
    """bech32_account_address_prefix is the account address prefix"""
    def __init__(
        self,
        *,
        bech32_account_address_prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bech32_account_address_prefix", b"bech32_account_address_prefix"]) -> None: ...

global___ConfigurationDescriptor = ConfigurationDescriptor

@typing_extensions.final
class MsgDescriptor(google.protobuf.message.Message):
    """MsgDescriptor describes a cosmos-sdk message that can be delivered with a transaction"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    msg_type_url: builtins.str
    """msg_type_url contains the TypeURL of a sdk.Msg."""
    def __init__(
        self,
        *,
        msg_type_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_type_url", b"msg_type_url"]) -> None: ...

global___MsgDescriptor = MsgDescriptor

@typing_extensions.final
class GetAuthnDescriptorRequest(google.protobuf.message.Message):
    """GetAuthnDescriptorRequest is the request used for the GetAuthnDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAuthnDescriptorRequest = GetAuthnDescriptorRequest

@typing_extensions.final
class GetAuthnDescriptorResponse(google.protobuf.message.Message):
    """GetAuthnDescriptorResponse is the response returned by the GetAuthnDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHN_FIELD_NUMBER: builtins.int
    @property
    def authn(self) -> global___AuthnDescriptor:
        """authn describes how to authenticate to the application when sending transactions"""
    def __init__(
        self,
        *,
        authn: global___AuthnDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authn", b"authn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authn", b"authn"]) -> None: ...

global___GetAuthnDescriptorResponse = GetAuthnDescriptorResponse

@typing_extensions.final
class GetChainDescriptorRequest(google.protobuf.message.Message):
    """GetChainDescriptorRequest is the request used for the GetChainDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetChainDescriptorRequest = GetChainDescriptorRequest

@typing_extensions.final
class GetChainDescriptorResponse(google.protobuf.message.Message):
    """GetChainDescriptorResponse is the response returned by the GetChainDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAIN_FIELD_NUMBER: builtins.int
    @property
    def chain(self) -> global___ChainDescriptor:
        """chain describes application chain information"""
    def __init__(
        self,
        *,
        chain: global___ChainDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chain", b"chain"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chain", b"chain"]) -> None: ...

global___GetChainDescriptorResponse = GetChainDescriptorResponse

@typing_extensions.final
class GetCodecDescriptorRequest(google.protobuf.message.Message):
    """GetCodecDescriptorRequest is the request used for the GetCodecDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetCodecDescriptorRequest = GetCodecDescriptorRequest

@typing_extensions.final
class GetCodecDescriptorResponse(google.protobuf.message.Message):
    """GetCodecDescriptorResponse is the response returned by the GetCodecDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODEC_FIELD_NUMBER: builtins.int
    @property
    def codec(self) -> global___CodecDescriptor:
        """codec describes the application codec such as registered interfaces and implementations"""
    def __init__(
        self,
        *,
        codec: global___CodecDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["codec", b"codec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["codec", b"codec"]) -> None: ...

global___GetCodecDescriptorResponse = GetCodecDescriptorResponse

@typing_extensions.final
class GetConfigurationDescriptorRequest(google.protobuf.message.Message):
    """GetConfigurationDescriptorRequest is the request used for the GetConfigurationDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetConfigurationDescriptorRequest = GetConfigurationDescriptorRequest

@typing_extensions.final
class GetConfigurationDescriptorResponse(google.protobuf.message.Message):
    """GetConfigurationDescriptorResponse is the response returned by the GetConfigurationDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___ConfigurationDescriptor:
        """config describes the application's sdk.Config"""
    def __init__(
        self,
        *,
        config: global___ConfigurationDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config"]) -> None: ...

global___GetConfigurationDescriptorResponse = GetConfigurationDescriptorResponse

@typing_extensions.final
class GetQueryServicesDescriptorRequest(google.protobuf.message.Message):
    """GetQueryServicesDescriptorRequest is the request used for the GetQueryServicesDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetQueryServicesDescriptorRequest = GetQueryServicesDescriptorRequest

@typing_extensions.final
class GetQueryServicesDescriptorResponse(google.protobuf.message.Message):
    """GetQueryServicesDescriptorResponse is the response returned by the GetQueryServicesDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> global___QueryServicesDescriptor:
        """queries provides information on the available queryable services"""
    def __init__(
        self,
        *,
        queries: global___QueryServicesDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["queries", b"queries"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["queries", b"queries"]) -> None: ...

global___GetQueryServicesDescriptorResponse = GetQueryServicesDescriptorResponse

@typing_extensions.final
class GetTxDescriptorRequest(google.protobuf.message.Message):
    """GetTxDescriptorRequest is the request used for the GetTxDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetTxDescriptorRequest = GetTxDescriptorRequest

@typing_extensions.final
class GetTxDescriptorResponse(google.protobuf.message.Message):
    """GetTxDescriptorResponse is the response returned by the GetTxDescriptor RPC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TX_FIELD_NUMBER: builtins.int
    @property
    def tx(self) -> global___TxDescriptor:
        """tx provides information on msgs that can be forwarded to the application
        alongside the accepted transaction protobuf type
        """
    def __init__(
        self,
        *,
        tx: global___TxDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tx", b"tx"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tx", b"tx"]) -> None: ...

global___GetTxDescriptorResponse = GetTxDescriptorResponse

@typing_extensions.final
class QueryServicesDescriptor(google.protobuf.message.Message):
    """QueryServicesDescriptor contains the list of cosmos-sdk queriable services"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def query_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QueryServiceDescriptor]:
        """query_services is a list of cosmos-sdk QueryServiceDescriptor"""
    def __init__(
        self,
        *,
        query_services: collections.abc.Iterable[global___QueryServiceDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_services", b"query_services"]) -> None: ...

global___QueryServicesDescriptor = QueryServicesDescriptor

@typing_extensions.final
class QueryServiceDescriptor(google.protobuf.message.Message):
    """QueryServiceDescriptor describes a cosmos-sdk queryable service"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULLNAME_FIELD_NUMBER: builtins.int
    IS_MODULE_FIELD_NUMBER: builtins.int
    METHODS_FIELD_NUMBER: builtins.int
    fullname: builtins.str
    """fullname is the protobuf fullname of the service descriptor"""
    is_module: builtins.bool
    """is_module describes if this service is actually exposed by an application's module"""
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QueryMethodDescriptor]:
        """methods provides a list of query service methods"""
    def __init__(
        self,
        *,
        fullname: builtins.str = ...,
        is_module: builtins.bool = ...,
        methods: collections.abc.Iterable[global___QueryMethodDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fullname", b"fullname", "is_module", b"is_module", "methods", b"methods"]) -> None: ...

global___QueryServiceDescriptor = QueryServiceDescriptor

@typing_extensions.final
class QueryMethodDescriptor(google.protobuf.message.Message):
    """QueryMethodDescriptor describes a queryable method of a query service
    no other info is provided beside method name and tendermint queryable path
    because it would be redundant with the grpc reflection service
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    FULL_QUERY_PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name is the protobuf name (not fullname) of the method"""
    full_query_path: builtins.str
    """full_query_path is the path that can be used to query
    this method via tendermint abci.Query
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        full_query_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["full_query_path", b"full_query_path", "name", b"name"]) -> None: ...

global___QueryMethodDescriptor = QueryMethodDescriptor



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.lockup.tx_pb2

class MsgStub:
    """Msg defines the Msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    LockTokens: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.tx_pb2.MsgLockTokens,
        osmosis.lockup.tx_pb2.MsgLockTokensResponse,
    ]
    """LockTokens lock tokens"""
    BeginUnlockingAll: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.tx_pb2.MsgBeginUnlockingAll,
        osmosis.lockup.tx_pb2.MsgBeginUnlockingAllResponse,
    ]
    """BeginUnlockingAll begin unlocking all tokens"""
    BeginUnlocking: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.tx_pb2.MsgBeginUnlocking,
        osmosis.lockup.tx_pb2.MsgBeginUnlockingResponse,
    ]
    """MsgBeginUnlocking begins unlocking tokens by lock ID"""
    ExtendLockup: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.tx_pb2.MsgExtendLockup,
        osmosis.lockup.tx_pb2.MsgExtendLockupResponse,
    ]
    """MsgEditLockup edits the existing lockups by lock ID"""
    ForceUnlock: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.tx_pb2.MsgForceUnlock,
        osmosis.lockup.tx_pb2.MsgForceUnlockResponse,
    ]

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the Msg service."""

    @abc.abstractmethod
    def LockTokens(
        self,
        request: osmosis.lockup.tx_pb2.MsgLockTokens,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.tx_pb2.MsgLockTokensResponse:
        """LockTokens lock tokens"""
    @abc.abstractmethod
    def BeginUnlockingAll(
        self,
        request: osmosis.lockup.tx_pb2.MsgBeginUnlockingAll,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.tx_pb2.MsgBeginUnlockingAllResponse:
        """BeginUnlockingAll begin unlocking all tokens"""
    @abc.abstractmethod
    def BeginUnlocking(
        self,
        request: osmosis.lockup.tx_pb2.MsgBeginUnlocking,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.tx_pb2.MsgBeginUnlockingResponse:
        """MsgBeginUnlocking begins unlocking tokens by lock ID"""
    @abc.abstractmethod
    def ExtendLockup(
        self,
        request: osmosis.lockup.tx_pb2.MsgExtendLockup,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.tx_pb2.MsgExtendLockupResponse:
        """MsgEditLockup edits the existing lockups by lock ID"""
    @abc.abstractmethod
    def ForceUnlock(
        self,
        request: osmosis.lockup.tx_pb2.MsgForceUnlock,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.tx_pb2.MsgForceUnlockResponse: ...

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.staking.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the staking Msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateValidator: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.tx_pb2.MsgCreateValidator,
        cosmos.staking.v1beta1.tx_pb2.MsgCreateValidatorResponse,
    ]
    """CreateValidator defines a method for creating a new validator."""
    EditValidator: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.tx_pb2.MsgEditValidator,
        cosmos.staking.v1beta1.tx_pb2.MsgEditValidatorResponse,
    ]
    """EditValidator defines a method for editing an existing validator."""
    Delegate: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.tx_pb2.MsgDelegate,
        cosmos.staking.v1beta1.tx_pb2.MsgDelegateResponse,
    ]
    """Delegate defines a method for performing a delegation of coins
    from a delegator to a validator.
    """
    BeginRedelegate: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.tx_pb2.MsgBeginRedelegate,
        cosmos.staking.v1beta1.tx_pb2.MsgBeginRedelegateResponse,
    ]
    """BeginRedelegate defines a method for performing a redelegation
    of coins from a delegator and source validator to a destination validator.
    """
    Undelegate: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.tx_pb2.MsgUndelegate,
        cosmos.staking.v1beta1.tx_pb2.MsgUndelegateResponse,
    ]
    """Undelegate defines a method for performing an undelegation from a
    delegate and a validator.
    """

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the staking Msg service."""

    @abc.abstractmethod
    def CreateValidator(
        self,
        request: cosmos.staking.v1beta1.tx_pb2.MsgCreateValidator,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.tx_pb2.MsgCreateValidatorResponse:
        """CreateValidator defines a method for creating a new validator."""
    @abc.abstractmethod
    def EditValidator(
        self,
        request: cosmos.staking.v1beta1.tx_pb2.MsgEditValidator,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.tx_pb2.MsgEditValidatorResponse:
        """EditValidator defines a method for editing an existing validator."""
    @abc.abstractmethod
    def Delegate(
        self,
        request: cosmos.staking.v1beta1.tx_pb2.MsgDelegate,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.tx_pb2.MsgDelegateResponse:
        """Delegate defines a method for performing a delegation of coins
        from a delegator to a validator.
        """
    @abc.abstractmethod
    def BeginRedelegate(
        self,
        request: cosmos.staking.v1beta1.tx_pb2.MsgBeginRedelegate,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.tx_pb2.MsgBeginRedelegateResponse:
        """BeginRedelegate defines a method for performing a redelegation
        of coins from a delegator and source validator to a destination validator.
        """
    @abc.abstractmethod
    def Undelegate(
        self,
        request: cosmos.staking.v1beta1.tx_pb2.MsgUndelegate,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.tx_pb2.MsgUndelegateResponse:
        """Undelegate defines a method for performing an undelegation from a
        delegate and a validator.
        """

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params holds parameters for the incentives module"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISTR_EPOCH_IDENTIFIER_FIELD_NUMBER: builtins.int
    distr_epoch_identifier: builtins.str
    """distr_epoch_identifier is what epoch type distribution will be triggered by
    (day, week, etc.)
    """
    def __init__(
        self,
        *,
        distr_epoch_identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["distr_epoch_identifier", b"distr_epoch_identifier"]) -> None: ...

global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Pairs(google.protobuf.message.Message):
    """Pairs defines a repeated slice of Pair objects."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAIRS_FIELD_NUMBER: builtins.int
    @property
    def pairs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pair]: ...
    def __init__(
        self,
        *,
        pairs: collections.abc.Iterable[global___Pair] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pairs", b"pairs"]) -> None: ...

global___Pairs = Pairs

@typing_extensions.final
class Pair(google.protobuf.message.Message):
    """Pair defines a key/value bytes tuple."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    value: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
        value: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___Pair = Pair



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params holds parameters for the incentives module"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_CREATION_FEE_FIELD_NUMBER: builtins.int
    @property
    def pool_creation_fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        pool_creation_fee: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_creation_fee", b"pool_creation_fee"]) -> None: ...

global___Params = Params

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the gamm module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOLS_FIELD_NUMBER: builtins.int
    NEXT_POOL_NUMBER_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...
    next_pool_number: builtins.int
    """will be renamed to next_pool_id in an upcoming version"""
    @property
    def params(self) -> global___Params: ...
    def __init__(
        self,
        *,
        pools: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        next_pool_number: builtins.int = ...,
        params: global___Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_pool_number", b"next_pool_number", "params", b"params", "pools", b"pools"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.epochs.genesis_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryEpochsInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryEpochsInfoRequest = QueryEpochsInfoRequest

@typing_extensions.final
class QueryEpochsInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPOCHS_FIELD_NUMBER: builtins.int
    @property
    def epochs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.epochs.genesis_pb2.EpochInfo]: ...
    def __init__(
        self,
        *,
        epochs: collections.abc.Iterable[osmosis.epochs.genesis_pb2.EpochInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["epochs", b"epochs"]) -> None: ...

global___QueryEpochsInfoResponse = QueryEpochsInfoResponse

@typing_extensions.final
class QueryCurrentEpochRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> None: ...

global___QueryCurrentEpochRequest = QueryCurrentEpochRequest

@typing_extensions.final
class QueryCurrentEpochResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_EPOCH_FIELD_NUMBER: builtins.int
    current_epoch: builtins.int
    def __init__(
        self,
        *,
        current_epoch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_epoch", b"current_epoch"]) -> None: ...

global___QueryCurrentEpochResponse = QueryCurrentEpochResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.twap.v1beta1.query_pb2

class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.twap.v1beta1.query_pb2.ParamsRequest,
        osmosis.twap.v1beta1.query_pb2.ParamsResponse,
    ]
    ArithmeticTwap: grpc.UnaryUnaryMultiCallable[
        osmosis.twap.v1beta1.query_pb2.ArithmeticTwapRequest,
        osmosis.twap.v1beta1.query_pb2.ArithmeticTwapResponse,
    ]
    ArithmeticTwapToNow: grpc.UnaryUnaryMultiCallable[
        osmosis.twap.v1beta1.query_pb2.ArithmeticTwapToNowRequest,
        osmosis.twap.v1beta1.query_pb2.ArithmeticTwapToNowResponse,
    ]
    GeometricTwap: grpc.UnaryUnaryMultiCallable[
        osmosis.twap.v1beta1.query_pb2.GeometricTwapRequest,
        osmosis.twap.v1beta1.query_pb2.GeometricTwapResponse,
    ]
    GeometricTwapToNow: grpc.UnaryUnaryMultiCallable[
        osmosis.twap.v1beta1.query_pb2.GeometricTwapToNowRequest,
        osmosis.twap.v1beta1.query_pb2.GeometricTwapToNowResponse,
    ]

class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.twap.v1beta1.query_pb2.ParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.twap.v1beta1.query_pb2.ParamsResponse: ...
    @abc.abstractmethod
    def ArithmeticTwap(
        self,
        request: osmosis.twap.v1beta1.query_pb2.ArithmeticTwapRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.twap.v1beta1.query_pb2.ArithmeticTwapResponse: ...
    @abc.abstractmethod
    def ArithmeticTwapToNow(
        self,
        request: osmosis.twap.v1beta1.query_pb2.ArithmeticTwapToNowRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.twap.v1beta1.query_pb2.ArithmeticTwapToNowResponse: ...
    @abc.abstractmethod
    def GeometricTwap(
        self,
        request: osmosis.twap.v1beta1.query_pb2.GeometricTwapRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.twap.v1beta1.query_pb2.GeometricTwapResponse: ...
    @abc.abstractmethod
    def GeometricTwapToNow(
        self,
        request: osmosis.twap.v1beta1.query_pb2.GeometricTwapToNowRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.twap.v1beta1.query_pb2.GeometricTwapToNowResponse: ...

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import osmosis.downtime_detector.v1beta1.downtime_duration_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisDowntimeEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    LAST_DOWNTIME_FIELD_NUMBER: builtins.int
    duration: osmosis.downtime_detector.v1beta1.downtime_duration_pb2.Downtime.ValueType
    @property
    def last_downtime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        duration: osmosis.downtime_detector.v1beta1.downtime_duration_pb2.Downtime.ValueType = ...,
        last_downtime: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_downtime", b"last_downtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "last_downtime", b"last_downtime"]) -> None: ...

global___GenesisDowntimeEntry = GenesisDowntimeEntry

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the twap module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNTIMES_FIELD_NUMBER: builtins.int
    LAST_BLOCK_TIME_FIELD_NUMBER: builtins.int
    @property
    def downtimes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenesisDowntimeEntry]: ...
    @property
    def last_block_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        downtimes: collections.abc.Iterable[global___GenesisDowntimeEntry] | None = ...,
        last_block_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_block_time", b"last_block_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["downtimes", b"downtimes", "last_block_time", b"last_block_time"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.ibc_rate_limit.v1beta1.query_pb2

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsRequest,
        osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsResponse,
    ]
    """Params defines a gRPC query method that returns the ibc-rate-limit module's
    parameters.
    """

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsResponse:
        """Params defines a gRPC query method that returns the ibc-rate-limit module's
        parameters.
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.incentives.query_pb2

class QueryStub:
    """Query defines the gRPC querier service"""

    def __init__(self, channel: grpc.Channel) -> None: ...
    ModuleToDistributeCoins: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.ModuleToDistributeCoinsRequest,
        osmosis.incentives.query_pb2.ModuleToDistributeCoinsResponse,
    ]
    """ModuleToDistributeCoins returns coins that are going to be distributed"""
    GaugeByID: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.GaugeByIDRequest,
        osmosis.incentives.query_pb2.GaugeByIDResponse,
    ]
    """GaugeByID returns gauges by their respective ID"""
    Gauges: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.GaugesRequest,
        osmosis.incentives.query_pb2.GaugesResponse,
    ]
    """Gauges returns both upcoming and active gauges"""
    ActiveGauges: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.ActiveGaugesRequest,
        osmosis.incentives.query_pb2.ActiveGaugesResponse,
    ]
    """ActiveGauges returns active gauges"""
    ActiveGaugesPerDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.ActiveGaugesPerDenomRequest,
        osmosis.incentives.query_pb2.ActiveGaugesPerDenomResponse,
    ]
    """ActiveGaugesPerDenom returns active gauges by denom"""
    UpcomingGauges: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.UpcomingGaugesRequest,
        osmosis.incentives.query_pb2.UpcomingGaugesResponse,
    ]
    """Returns scheduled gauges that have not yet occured"""
    UpcomingGaugesPerDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.UpcomingGaugesPerDenomRequest,
        osmosis.incentives.query_pb2.UpcomingGaugesPerDenomResponse,
    ]
    """UpcomingGaugesPerDenom returns scheduled gauges that have not yet occured
    by denom
    """
    RewardsEst: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.RewardsEstRequest,
        osmosis.incentives.query_pb2.RewardsEstResponse,
    ]
    """RewardsEst returns an estimate of the rewards from now until a specified
    time in the future The querier either provides an address or a set of locks
    for which they want to find the associated rewards
    """
    LockableDurations: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.query_pb2.QueryLockableDurationsRequest,
        osmosis.incentives.query_pb2.QueryLockableDurationsResponse,
    ]
    """LockableDurations returns lockable durations that are valid to distribute
    incentives for
    """

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service"""

    @abc.abstractmethod
    def ModuleToDistributeCoins(
        self,
        request: osmosis.incentives.query_pb2.ModuleToDistributeCoinsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.ModuleToDistributeCoinsResponse:
        """ModuleToDistributeCoins returns coins that are going to be distributed"""
    @abc.abstractmethod
    def GaugeByID(
        self,
        request: osmosis.incentives.query_pb2.GaugeByIDRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.GaugeByIDResponse:
        """GaugeByID returns gauges by their respective ID"""
    @abc.abstractmethod
    def Gauges(
        self,
        request: osmosis.incentives.query_pb2.GaugesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.GaugesResponse:
        """Gauges returns both upcoming and active gauges"""
    @abc.abstractmethod
    def ActiveGauges(
        self,
        request: osmosis.incentives.query_pb2.ActiveGaugesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.ActiveGaugesResponse:
        """ActiveGauges returns active gauges"""
    @abc.abstractmethod
    def ActiveGaugesPerDenom(
        self,
        request: osmosis.incentives.query_pb2.ActiveGaugesPerDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.ActiveGaugesPerDenomResponse:
        """ActiveGaugesPerDenom returns active gauges by denom"""
    @abc.abstractmethod
    def UpcomingGauges(
        self,
        request: osmosis.incentives.query_pb2.UpcomingGaugesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.UpcomingGaugesResponse:
        """Returns scheduled gauges that have not yet occured"""
    @abc.abstractmethod
    def UpcomingGaugesPerDenom(
        self,
        request: osmosis.incentives.query_pb2.UpcomingGaugesPerDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.UpcomingGaugesPerDenomResponse:
        """UpcomingGaugesPerDenom returns scheduled gauges that have not yet occured
        by denom
        """
    @abc.abstractmethod
    def RewardsEst(
        self,
        request: osmosis.incentives.query_pb2.RewardsEstRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.RewardsEstResponse:
        """RewardsEst returns an estimate of the rewards from now until a specified
        time in the future The querier either provides an address or a set of locks
        for which they want to find the associated rewards
        """
    @abc.abstractmethod
    def LockableDurations(
        self,
        request: osmosis.incentives.query_pb2.QueryLockableDurationsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.query_pb2.QueryLockableDurationsResponse:
        """LockableDurations returns lockable durations that are valid to distribute
        incentives for
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.lockup import tx_pb2 as osmosis_dot_lockup_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LockTokens = channel.unary_unary(
                '/osmosis.lockup.Msg/LockTokens',
                request_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgLockTokens.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgLockTokensResponse.FromString,
                )
        self.BeginUnlockingAll = channel.unary_unary(
                '/osmosis.lockup.Msg/BeginUnlockingAll',
                request_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingAll.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingAllResponse.FromString,
                )
        self.BeginUnlocking = channel.unary_unary(
                '/osmosis.lockup.Msg/BeginUnlocking',
                request_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlocking.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingResponse.FromString,
                )
        self.ExtendLockup = channel.unary_unary(
                '/osmosis.lockup.Msg/ExtendLockup',
                request_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgExtendLockup.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgExtendLockupResponse.FromString,
                )
        self.ForceUnlock = channel.unary_unary(
                '/osmosis.lockup.Msg/ForceUnlock',
                request_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgForceUnlock.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgForceUnlockResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def LockTokens(self, request, context):
        """LockTokens lock tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BeginUnlockingAll(self, request, context):
        """BeginUnlockingAll begin unlocking all tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BeginUnlocking(self, request, context):
        """MsgBeginUnlocking begins unlocking tokens by lock ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExtendLockup(self, request, context):
        """MsgEditLockup edits the existing lockups by lock ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ForceUnlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LockTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.LockTokens,
                    request_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgLockTokens.FromString,
                    response_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgLockTokensResponse.SerializeToString,
            ),
            'BeginUnlockingAll': grpc.unary_unary_rpc_method_handler(
                    servicer.BeginUnlockingAll,
                    request_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingAll.FromString,
                    response_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingAllResponse.SerializeToString,
            ),
            'BeginUnlocking': grpc.unary_unary_rpc_method_handler(
                    servicer.BeginUnlocking,
                    request_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlocking.FromString,
                    response_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingResponse.SerializeToString,
            ),
            'ExtendLockup': grpc.unary_unary_rpc_method_handler(
                    servicer.ExtendLockup,
                    request_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgExtendLockup.FromString,
                    response_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgExtendLockupResponse.SerializeToString,
            ),
            'ForceUnlock': grpc.unary_unary_rpc_method_handler(
                    servicer.ForceUnlock,
                    request_deserializer=osmosis_dot_lockup_dot_tx__pb2.MsgForceUnlock.FromString,
                    response_serializer=osmosis_dot_lockup_dot_tx__pb2.MsgForceUnlockResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.lockup.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def LockTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Msg/LockTokens',
            osmosis_dot_lockup_dot_tx__pb2.MsgLockTokens.SerializeToString,
            osmosis_dot_lockup_dot_tx__pb2.MsgLockTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BeginUnlockingAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Msg/BeginUnlockingAll',
            osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingAll.SerializeToString,
            osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingAllResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BeginUnlocking(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Msg/BeginUnlocking',
            osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlocking.SerializeToString,
            osmosis_dot_lockup_dot_tx__pb2.MsgBeginUnlockingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExtendLockup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Msg/ExtendLockup',
            osmosis_dot_lockup_dot_tx__pb2.MsgExtendLockup.SerializeToString,
            osmosis_dot_lockup_dot_tx__pb2.MsgExtendLockupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ForceUnlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Msg/ForceUnlock',
            osmosis_dot_lockup_dot_tx__pb2.MsgForceUnlock.SerializeToString,
            osmosis_dot_lockup_dot_tx__pb2.MsgForceUnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
